# -*- coding: utf-8 -*-
# flake8: noqa
from ._api import (
    decompress, Decompressor, compress, BrotliEncoderMode, DEFAULT_MODE,
    Compressor, MODE_GENERIC, MODE_TEXT, MODE_FONT, error, Error
)

__version__ = "1.0.9.2"
